@@ -6,7 +6,7 @@
 #include "ktimezonecomboboxtest.h"
 #include "../src/ktimezonecombobox.h"
 
-#include "qtest.h"
+#include <QTest>
 
 #include <QTimeZone>
 
@@ -107,3 +107,5 @@ void KTimeZoneComboBoxTest::test_convenience()
     QVERIFY(!combo.isFloating());
     QCOMPARE(combo.selectedTimeZone(), QTimeZone::utc());
 }
+
+#include "moc_ktimezonecomboboxtest.cpp"
