@@ -10,6 +10,7 @@
 
 #include "attachmenteditdialog.h"
 #include "attachmenticonview.h"
+#include "config-enterprise.h"
 #include "ui_attachmenteditdialog.h"
 #include <KIO/StoredTransferJob>
 #include <KJobWidgets>
@@ -72,7 +73,7 @@ AttachmentEditDialog::AttachmentEditDialog(AttachmentIconItem *item, QWidget *pa
 
     connect(mUi->mInlineCheck, &QCheckBox::stateChanged, this, &AttachmentEditDialog::inlineChanged);
     connect(mUi->mURLRequester,
-            qOverload<const QUrl &>(&KUrlRequester::urlSelected),
+            &KUrlRequester::urlSelected,
             this,
             static_cast<void (AttachmentEditDialog::*)(const QUrl &)>(&AttachmentEditDialog::urlChanged));
     connect(mUi->mURLRequester,
@@ -168,3 +169,5 @@ void AttachmentEditDialog::urlChanged(const QUrl &url)
     mUi->mTypeLabel->setText(mMimeType.comment());
     mUi->mIcon->setPixmap(AttachmentIconItem::icon(mMimeType, url.path()));
 }
+
+#include "moc_attachmenteditdialog.cpp"
