@@ -264,14 +264,10 @@ QString IncidenceAlarm::stringForAlarm(const KCalendarCore::Alarm::Ptr &alarm)
 
     QString action;
     switch (alarm->type()) {
-    case KCalendarCore::Alarm::Display:
-        action = i18nc("Alarm action", "Display a dialog");
-        break;
     case KCalendarCore::Alarm::Procedure:
-        action = i18nc("Alarm action", "Execute a script");
-        break;
+    case KCalendarCore::Alarm::Display:
     case KCalendarCore::Alarm::Email:
-        action = i18nc("Alarm action", "Send an email");
+        action = i18nc("Alarm action", "Display a dialog");
         break;
     case KCalendarCore::Alarm::Audio:
         action = i18nc("Alarm action", "Play an audio file");
@@ -380,3 +376,5 @@ QString IncidenceAlarm::stringForAlarm(const KCalendarCore::Alarm::Ptr &alarm)
         }
     }
 }
+
+#include "moc_incidencealarm.cpp"
