@@ -19,6 +19,7 @@
 #include <KActionCollection>
 #include <KIO/Job>
 #include <KIO/JobUiDelegate>
+#include <KIO/JobUiDelegateFactory>
 #include <KIO/OpenUrlJob>
 #include <KIO/StoredTransferJob>
 #include <KJobWidgets>
@@ -187,13 +188,13 @@ void IncidenceAttachment::removeSelectedAttachments()
 
     QString labelsStr = labels.join(QLatin1String("<nl/>"));
 
-    if (KMessageBox::questionYesNo(nullptr,
-                                   xi18nc("@info", "Do you really want to remove these attachments?<nl/>%1", labelsStr),
-                                   i18nc("@title:window", "Remove Attachments?"),
-                                   KStandardGuiItem::remove(),
-                                   KStandardGuiItem::cancel(),
-                                   QStringLiteral("calendarRemoveAttachments"))
-        != KMessageBox::Yes) {
+    if (KMessageBox::questionTwoActions(nullptr,
+                                        xi18nc("@info", "Do you really want to remove these attachments?<nl/>%1", labelsStr),
+                                        i18nc("@title:window", "Remove Attachments?"),
+                                        KStandardGuiItem::remove(),
+                                        KStandardGuiItem::cancel(),
+                                        QStringLiteral("calendarRemoveAttachments"))
+        != KMessageBox::ButtonCode::PrimaryAction) {
         return;
     }
 
@@ -270,7 +271,7 @@ void IncidenceAttachment::showAttachment(QListWidgetItem *item)
         openURL(QUrl(att.uri()));
     } else {
         auto job = new KIO::OpenUrlJob(attitem->tempFileForAttachment(), att.mimeType());
-        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, mAttachmentView));
+        job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, mAttachmentView));
         job->setDeleteTemporaryFile(true);
         job->start();
     }
@@ -586,3 +587,5 @@ void IncidenceAttachment::addUriAttachment(const QString &uri, const QString &mi
         }
     }
 }
+
+#include "moc_incidenceattachment.cpp"
