@@ -37,6 +37,8 @@
 #include <QPointer>
 #include <QTreeView>
 
+Q_DECLARE_METATYPE(IncidenceEditorNG::EditorConfig::Organizer)
+
 using namespace IncidenceEditorNG;
 
 IncidenceAttendee::IncidenceAttendee(QWidget *parent, IncidenceDateTime *dateTime, Ui::EventOrTodoDesktop *ui)
@@ -91,6 +93,7 @@ IncidenceAttendee::IncidenceAttendee(QWidget *parent, IncidenceDateTime *dateTim
     mUi->mOrganizerStack->setCurrentIndex(0);
 
     fillOrganizerCombo();
+    slotUpdateCryptoPreferences();
     mUi->mSolveButton->setEnabled(false);
     mUi->mOrganizerLabel->setVisible(false);
 
@@ -107,6 +110,7 @@ IncidenceAttendee::IncidenceAttendee(QWidget *parent, IncidenceDateTime *dateTim
             this, &IncidenceAttendee::slotOrganizerChanged);
     */
     connect(mUi->mOrganizerCombo, &QComboBox::currentIndexChanged, this, &IncidenceAttendee::checkDirtyStatus);
+    connect(mUi->mOrganizerCombo, &QComboBox::currentIndexChanged, this, &IncidenceAttendee::slotUpdateCryptoPreferences);
 
     connect(mDateTime, &IncidenceDateTime::startDateChanged, this, &IncidenceAttendee::slotEventDurationChanged);
     connect(mDateTime, &IncidenceDateTime::endDateChanged, this, &IncidenceAttendee::slotEventDurationChanged);
@@ -123,12 +127,14 @@ IncidenceAttendee::IncidenceAttendee(QWidget *parent, IncidenceDateTime *dateTim
 
     // conflict resolver (should show also resources)
     connect(mDataModel, &AttendeeTableModel::layoutChanged, this, &IncidenceAttendee::slotConflictResolverLayoutChanged);
+    connect(mDataModel, &AttendeeTableModel::modelReset, this, &IncidenceAttendee::slotConflictResolverLayoutChanged);
     connect(mDataModel, &AttendeeTableModel::rowsAboutToBeRemoved, this, &IncidenceAttendee::slotConflictResolverAttendeeRemoved);
     connect(mDataModel, &AttendeeTableModel::rowsInserted, this, &IncidenceAttendee::slotConflictResolverAttendeeAdded);
     connect(mDataModel, &AttendeeTableModel::dataChanged, this, &IncidenceAttendee::slotConflictResolverAttendeeChanged);
 
     // Group substitution
     connect(filterProxyModel, &AttendeeFilterProxyModel::layoutChanged, this, &IncidenceAttendee::slotGroupSubstitutionLayoutChanged);
+    connect(filterProxyModel, &AttendeeFilterProxyModel::modelReset, this, &IncidenceAttendee::slotGroupSubstitutionLayoutChanged);
     connect(filterProxyModel, &AttendeeFilterProxyModel::rowsAboutToBeRemoved, this, &IncidenceAttendee::slotGroupSubstitutionAttendeeRemoved);
     connect(filterProxyModel, &AttendeeFilterProxyModel::rowsInserted, this, &IncidenceAttendee::slotGroupSubstitutionAttendeeAdded);
     connect(filterProxyModel, &AttendeeFilterProxyModel::dataChanged, this, &IncidenceAttendee::slotGroupSubstitutionAttendeeChanged);
@@ -139,6 +145,8 @@ IncidenceAttendee::IncidenceAttendee(QWidget *parent, IncidenceDateTime *dateTim
     connect(filterProxyModel, &AttendeeFilterProxyModel::dataChanged, this, &IncidenceAttendee::updateCount);
     connect(filterProxyModel, &AttendeeFilterProxyModel::layoutChanged, this, &IncidenceAttendee::updateCount);
     connect(filterProxyModel, &AttendeeFilterProxyModel::layoutChanged, this, &IncidenceAttendee::filterLayoutChanged);
+    connect(filterProxyModel, &AttendeeFilterProxyModel::modelReset, this, &IncidenceAttendee::updateCount);
+    connect(filterProxyModel, &AttendeeFilterProxyModel::modelReset, this, &IncidenceAttendee::filterLayoutChanged);
 }
 
 IncidenceAttendee::~IncidenceAttendee() = default;
@@ -308,14 +316,16 @@ void IncidenceAttendee::declineForMe()
 void IncidenceAttendee::fillOrganizerCombo()
 {
     mUi->mOrganizerCombo->clear();
-    const QStringList lst = IncidenceEditorNG::EditorConfig::instance()->fullEmails();
-    QStringList uniqueList;
-    for (QStringList::ConstIterator it = lst.begin(), end = lst.end(); it != end; ++it) {
-        if (!uniqueList.contains(*it)) {
-            uniqueList << *it;
+    const auto organizers = IncidenceEditorNG::EditorConfig::instance()->allOrganizers();
+    for (auto organizer = organizers.cbegin(), end = organizers.cend(); organizer != end; ++organizer) {
+        if (std::any_of(organizers.cbegin(), organizer, [organizer](const auto &pastOrg) {
+                return organizer->email == pastOrg.email && organizer->name == pastOrg.name;
+            })) {
+            continue;
         }
+
+        mUi->mOrganizerCombo->addItem(QStringLiteral("%1 <%2>").arg(organizer->name, organizer->email), QVariant::fromValue(*organizer));
     }
-    mUi->mOrganizerCombo->addItems(uniqueList);
 }
 
 void IncidenceAttendee::checkIfExpansionIsNeeded(const KCalendarCore::Attendee &attendee)
@@ -418,8 +428,7 @@ void IncidenceAttendee::insertAddresses(const KContacts::Addressee::List &list)
 void IncidenceAttendee::slotSelectAddresses()
 {
     QPointer<Akonadi::AbstractEmailAddressSelectionDialog> dialog;
-    const KPluginMetaData editWidgetPlugin(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR))
-                                           + QStringLiteral("/akonadi/emailaddressselectionldapdialogplugin"));
+    const KPluginMetaData editWidgetPlugin(QStringLiteral("pim6/akonadi/emailaddressselectionldapdialogplugin"));
 
     const auto result = KPluginFactory::instantiatePlugin<Akonadi::AbstractEmailAddressSelectionDialog>(editWidgetPlugin, mParentWidget);
     if (result) {
@@ -950,3 +959,17 @@ int IncidenceAttendee::rowOfAttendee(const QString &uid) const
     });
     return std::distance(attendees.begin(), it);
 }
+
+void IncidenceAttendee::slotUpdateCryptoPreferences()
+{
+    const auto idx = mUi->mOrganizerCombo->currentIndex();
+    if (idx < 0) {
+        return;
+    }
+    const auto organizer = mUi->mOrganizerCombo->currentData().value<EditorConfig::Organizer>();
+
+    mUi->mSignItip->setChecked(organizer.sign);
+    mUi->mEncryptItip->setChecked(organizer.encrypt);
+}
+
+#include "moc_incidenceattendee.cpp"
