@@ -21,9 +21,7 @@ namespace IncidenceEditorNG
 class IncidenceDescriptionPrivate
 {
 public:
-    IncidenceDescriptionPrivate()
-    {
-    }
+    IncidenceDescriptionPrivate() = default;
 
     QString mRealOriginalDescriptionEditContents;
     bool mRichTextEnabled = false;
@@ -191,3 +189,5 @@ void IncidenceDescription::printDebugInfo() const
         qCDebug(INCIDENCEEDITOR_LOG) << "Incidence is invalid";
     }
 }
+
+#include "moc_incidencedescription.cpp"
