@@ -27,7 +27,7 @@ public:
     {
     }
 
-    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role) const override
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role) const override
     {
         QVariant d;
         if (role == Qt::DisplayRole || role == Qt::EditRole) {
@@ -83,9 +83,11 @@ IncidenceResource::IncidenceResource(IncidenceAttendee *ieAttendee, IncidenceDat
     connect(mUi->mFindResourcesButton, &QPushButton::clicked, this, &IncidenceResource::findResources);
     connect(mUi->mBookResourceButton, &QPushButton::clicked, this, &IncidenceResource::bookResource);
     connect(filterProxyModel, &ResourceFilterProxyModel::layoutChanged, this, &IncidenceResource::layoutChanged);
+    connect(filterProxyModel, &ResourceFilterProxyModel::modelReset, this, &IncidenceResource::layoutChanged);
     connect(filterProxyModel, &ResourceFilterProxyModel::layoutChanged, this, &IncidenceResource::updateCount);
     connect(filterProxyModel, &ResourceFilterProxyModel::rowsInserted, this, &IncidenceResource::updateCount);
     connect(filterProxyModel, &ResourceFilterProxyModel::rowsRemoved, this, &IncidenceResource::updateCount);
+    connect(filterProxyModel, &ResourceFilterProxyModel::modelReset, this, &IncidenceResource::updateCount);
     // only update when FullName is changed
     connect(filterProxyModel, &ResourceFilterProxyModel::dataChanged, this, &IncidenceResource::updateCount);
 }
@@ -183,3 +185,5 @@ int IncidenceResource::resourceCount() const
     }
     return c;
 }
+
+#include "moc_incidenceresource.cpp"
